(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     30035,        636]
NotebookOptionsPosition[     30495,        629]
NotebookOutlinePosition[     30961,        649]
CellTagsIndexPosition[     30918,        646]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Stress on over-constrained bar\n", "Title",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox["Mengtian Yin, Baoxing Xu\nUniversity of Virginia, 2019-02-26",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Text",
 TextAlignment->Center,
 ExpressionUUID -> "d890e306-93c5-4bdb-a099-038368ecbb65"],

Cell[TextData[{
 "Consider two shafts bounded by two rigid walls. A uniform force or torque \
is applied on the interface between two shafts, and thus results in an axial \
deformation or twisting of shafts. When force is applied, equation ",
 Cell[BoxData[
  FormBox[
   RowBox[{"E", "=", 
    FractionBox["\[Sigma]", "\[Epsilon]"]}], TraditionalForm]],
  ExpressionUUID -> "55fa591f-c945-4365-b8e9-f4411b1b821f"],
 " is used to solve for reaction force applied from walls to shafts, where E \
is the young\[CloseCurlyQuote]s modulus, \[Sigma] is the stress, \[Epsilon] \
is the strain. Since the summation of deformation of two shafts must be 0 (as \
two walls are rigid), ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Epsilon]", "Left"], TraditionalForm]],
  ExpressionUUID -> "9b87bc89-689f-454b-822b-6a3a8e33ca2b"],
 " + ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Epsilon]", "Right"], TraditionalForm]],
  ExpressionUUID -> "dfdfff97-28e5-42bd-a279-f8b5258d70cb"],
 "= 0. Also, the summation of two reaction forces from walls must equals to \
F, the force applied, since the system is in equilibrium condition. Solving \
these two equations simultaneously gives the numerical solution of two \
reaction forces, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "1"], TraditionalForm]],
  ExpressionUUID -> "f10a3e38-fcab-433b-a5ed-4abfcc0d7cef"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "2"], TraditionalForm]],
  ExpressionUUID -> "bbf4eaea-c28b-4de2-a2c5-2f3d3e3dbb09"],
 ". \nSimilar procedure can be taken to solve for the torques applied from \
walls to shafts when a torque is applied to the interface between two shafts. \
 Equation \[CurlyPhi] = ",
 Cell[BoxData[
  FormBox[
   FractionBox["TL", "GJ"], TraditionalForm]],
  ExpressionUUID -> "f0e1d26c-c1ad-42f4-b01d-bc6d70dec077"],
 " and T=",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "1"], TraditionalForm]],
  ExpressionUUID -> "783aaf9a-d2fb-447e-8a26-49604b5de456"],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "2"], TraditionalForm]],
  ExpressionUUID -> "1abfc7cb-c96b-48db-a91a-566a313b0102"],
 " are used instead, where \[CurlyPhi] is the twisting angle of the shaft, T \
is the torque, L is the length, G is the shear modulus, J is the polar moment \
of inertia of the cross section area. "
}], "Text",
 ExpressionUUID -> "117980bf-5498-4d14-8702-14a0b27fe172"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`E1$$ = 200, $CellContext`E2$$ = 
    200, $CellContext`F$$ = 10, $CellContext`G1$$ = 4, $CellContext`G2$$ = 
    4, $CellContext`opa$$ = 1, $CellContext`opa1$$ = 0, $CellContext`opa2$$ = 
    0, $CellContext`Pos$$ = 0.46, $CellContext`pv$$ = 0, $CellContext`R1$$ = 
    0.1, $CellContext`R2$$ = 0.05, $CellContext`reset$$ = 
    False, $CellContext`T$$ = 0.5, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`pv$$], 0, 
       Row[{"Point of View", 
         Spacer[10]}]}, {0 -> "3D", 1 -> "Y-Z Plane", 2 -> "X-Y Plane"}}, {{
       Hold[$CellContext`Pos$$], 0.5, 
       Row[{"Position of Loading Force or Torque", 
         Spacer[10]}]}, 0.01, 0.99, 0.01}, {{
       Hold[$CellContext`R1$$], 0.1, 
       Row[{"Radius of Shaft 1 [m]", 
         Spacer[85]}]}, 0.025, 0.1, 0.01}, {{
       Hold[$CellContext`R2$$], 0.05, 
       Row[{"Radius of Shaft 2 [m]", 
         Spacer[85]}]}, 0.025, 0.1, 0.01}, {{
       Hold[$CellContext`opa$$], 1, 
       Row[{
        "\!\(\*\nStyleBox[\"Switch\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"Mode\",\n\
FontWeight->\"Bold\"]\)", 
         Spacer[22]}]}, {1 -> "Force", 0 -> "Torque"}}, {{
       Hold[$CellContext`F$$], 10, 
       Row[{"Force Applied on the Disk [N]", 
         Spacer[45]}]}, -100, 100, 0.1}, {{
       Hold[$CellContext`E1$$], 200, 
       Row[{"Young's Modulus of Shaft 1 [GPa]", 
         Spacer[22]}]}, 0, 200}, {{
       Hold[$CellContext`E2$$], 200, 
       Row[{"Young's Modulus of Shaft 2 [GPa]", 
         Spacer[22]}]}, 0, 200}, {{
       Hold[$CellContext`opa1$$], 0, 
       Row[{"Show Result", 
         Spacer[10]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`T$$], 0.5, 
       Row[{"Torque Applied on the Disk [kN\[CenterDot]m]", 
         Spacer[38]}]}, -1, 1, 0.01}, {{
       Hold[$CellContext`G1$$], 4, 
       Row[{"Shear Modulus of Shaft 1 [MPa]", 
         Spacer[50]}]}, 4, 10}, {{
       Hold[$CellContext`G2$$], 4, 
       Row[{"Shear Modulus of Shaft 2 [MPa]", 
         Spacer[50]}]}, 4, 10}, {{
       Hold[$CellContext`opa2$$], 0, 
       Row[{"Show Result", 
         Spacer[10]}]}, {1 -> "On", 0 -> "Off"}}, {
      Hold[
       Grid[{{
          Manipulate`Place[1]}, {
          Button[
          "Reset view", $CellContext`reset$$ = True, ImageSize -> {90, 30}]}, {
          Manipulate`Place[2]}, {
          Manipulate`Place[3]}, {
          Manipulate`Place[4]}, {
          Row[{"--------------------------------------------------"}]}, {
          Manipulate`Place[5]}, {
          PaneSelector[{1 -> Column[{
               
               Row[{"\!\(\*\nStyleBox[\"Type\",\nFontWeight->\"Plain\"]\)\!\(\
\*\nStyleBox[\" \",\nFontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\"I\",\n\
FontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Plain\"]\)\!\(\
\*\nStyleBox[\" \",\nFontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\"Force\",\n\
FontWeight->\"Plain\"]\)"}], 
               Manipulate`Place[6], 
               Manipulate`Place[7], 
               Manipulate`Place[8], 
               Manipulate`Place[9], 
               Row[{
                 Dynamic[
                  If[$CellContext`opa1$$ == 1, $CellContext`label1, 
                   Invisible[$CellContext`temp]]]}]}, Spacings -> 1.75], 0 -> 
            Column[{
               
               Row[{"\!\(\*\nStyleBox[\"Type\",\nFontWeight->\"Plain\"]\)\!\(\
\*\nStyleBox[\" \",\nFontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\"II\",\n\
FontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\":\",\nFontWeight->\"Plain\"]\)\!\(\
\*\nStyleBox[\" \",\nFontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\"Torque\",\n\
FontWeight->\"Plain\"]\)"}], 
               Manipulate`Place[10], 
               Manipulate`Place[11], 
               Manipulate`Place[12], 
               Manipulate`Place[13], 
               Row[{
                 Dynamic[
                  If[$CellContext`opa2$$ == 1, $CellContext`label2, 
                   Invisible[$CellContext`temp]]]}]}, Spacings -> 1.75]}, 
           Dynamic[$CellContext`opa$$]]}}, Alignment -> Left, 
        Spacings -> {Automatic, 1.5}]], Manipulate`Dump`ThisIsNotAControl}, {{
       Hold[$CellContext`reset$$], False}, 0}}, Typeset`size$$ = {
    625., {482., 489.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`pv$3200$$ = 
    False, $CellContext`Pos$3201$$ = 0, $CellContext`R1$3202$$ = 
    0, $CellContext`R2$3203$$ = 0, $CellContext`opa$3204$$ = 
    False, $CellContext`F$3205$$ = 0, $CellContext`E1$3206$$ = 
    0, $CellContext`E2$3207$$ = 0, $CellContext`opa1$3208$$ = 
    False, $CellContext`T$3209$$ = 0, $CellContext`G1$3210$$ = 
    0, $CellContext`G2$3211$$ = 0, $CellContext`opa2$3212$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`E1$$ = 200, $CellContext`E2$$ = 
        200, $CellContext`F$$ = 10, $CellContext`G1$$ = 4, $CellContext`G2$$ = 
        4, $CellContext`opa$$ = 1, $CellContext`opa1$$ = 
        0, $CellContext`opa2$$ = 0, $CellContext`Pos$$ = 
        0.5, $CellContext`pv$$ = 0, $CellContext`R1$$ = 
        0.1, $CellContext`R2$$ = 0.05, $CellContext`reset$$ = 
        False, $CellContext`T$$ = 0.5}, "ControllerVariables" :> {
        Hold[$CellContext`pv$$, $CellContext`pv$3200$$, False], 
        Hold[$CellContext`Pos$$, $CellContext`Pos$3201$$, 0], 
        Hold[$CellContext`R1$$, $CellContext`R1$3202$$, 0], 
        Hold[$CellContext`R2$$, $CellContext`R2$3203$$, 0], 
        Hold[$CellContext`opa$$, $CellContext`opa$3204$$, False], 
        Hold[$CellContext`F$$, $CellContext`F$3205$$, 0], 
        Hold[$CellContext`E1$$, $CellContext`E1$3206$$, 0], 
        Hold[$CellContext`E2$$, $CellContext`E2$3207$$, 0], 
        Hold[$CellContext`opa1$$, $CellContext`opa1$3208$$, False], 
        Hold[$CellContext`T$$, $CellContext`T$3209$$, 0], 
        Hold[$CellContext`G1$$, $CellContext`G1$3210$$, 0], 
        Hold[$CellContext`G2$$, $CellContext`G2$3211$$, 0], 
        Hold[$CellContext`opa2$$, $CellContext`opa2$3212$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`L0$, $CellContext`R0$, $CellContext`size$, \
$CellContext`reset1$, $CellContext`sign$, $CellContext`pd$, $CellContext`nd$, \
$CellContext`settings1$, $CellContext`settings2$, $CellContext`label$, \
$CellContext`view$, $CellContext`dwf1$, $CellContext`dwf2$, \
$CellContext`dwf3$, $CellContext`dwf4$, $CellContext`dwf5$, \
$CellContext`dwf6$, $CellContext`dwf7$, $CellContext`dwf8$, \
$CellContext`dwf9$, $CellContext`dwf10$, $CellContext`dwf11$, \
$CellContext`dwf12$, $CellContext`dwf13$, $CellContext`dwf14$, \
$CellContext`dwf15$, $CellContext`dwf16$, $CellContext`dw1$, \
$CellContext`dw2$, $CellContext`dw3$}, $CellContext`L0$ = 1; $CellContext`R0$ = 
         0.1; $CellContext`size$ = 1.2 $CellContext`L0$; $CellContext`reset1$ = 
         If[$CellContext`reset$$, $CellContext`reset$$ = False; False, 
           True]; $CellContext`L = 1; 
        If[$CellContext`pv$$ == 
          0, $CellContext`view$ = {(1. 
             100) $CellContext`size$, (-100) $CellContext`size$, (0.75 
             100) $CellContext`size$}, 
          
          If[$CellContext`pv$$ == 
           1, $CellContext`view$ = {
            100 $CellContext`size$, 0, 0}, $CellContext`view$ = {
            0, 0, 100 $CellContext`size$}]]; $CellContext`settings1$ = {
          Boxed -> False, ViewPoint -> $CellContext`view$, SphericalRegion -> 
           True, ImageSize -> 500, 
           PlotRange -> {{(-0.05) $CellContext`size$, 
              0.9 $CellContext`size$}, {(-0.3) $CellContext`size$, 
              0.3 $CellContext`size$}, {(-0.2) $CellContext`size$, 
              0.2 $CellContext`size$}}}; $CellContext`settings2$ = {
          Boxed -> False, ViewPoint -> $CellContext`view$, SphericalRegion -> 
           True, ImageSize -> 400, PlotRange -> {{-0.35, 1.35}, {-0.2, 0.6}}}; 
        If[$CellContext`R1$$ > $CellContext`R2$$, $CellContext`R = \
$CellContext`R1$$, $CellContext`R = $CellContext`R2$$]; 
        If[$CellContext`F$$ > 0, $CellContext`x = -0.1, $CellContext`x = 0.1]; 
        If[$CellContext`T$$ > 0, $CellContext`y = 1, $CellContext`y = -1]; 
        If[$CellContext`F$$ == 0, $CellContext`a = 0, $CellContext`a = 1]; 
        If[$CellContext`T$$ == 0, $CellContext`b = 0, $CellContext`b = 
          1]; $CellContext`F1 = $CellContext`F$$/((($CellContext`R2$$^2 \
$CellContext`E2$$) 10^9)/(($CellContext`R1$$^2 $CellContext`E1$$) 10^9) + 
          1); $CellContext`F2 = $CellContext`F$$ - $CellContext`F1; \
$CellContext`label1 = 
         Grid[{{"\!\(\*\nStyleBox[\"F1\",\nFontColor->RGBColor[0, 0, 1]]\) =  \
", 
             Round[$CellContext`F1, 0.01], "N"}, {
            "\!\(\*\nStyleBox[\"F2\",\nFontColor->RGBColor[1, 0, 0]]\) = ", 
             Round[$CellContext`F2, 0.01], "N"}}, Alignment -> 
           Left]; $CellContext`T1 = $CellContext`T$$/(((($CellContext`G2$$ 
              10^6) $CellContext`R2$$^4) \
$CellContext`Pos$$)/((($CellContext`G1$$ 
             10^6) $CellContext`R1$$^4) ($CellContext`L - \
$CellContext`Pos$$)) + 
          1); $CellContext`T2 = $CellContext`T$$ - $CellContext`T1; \
$CellContext`label2 = 
         Grid[{{"\!\(\*\nStyleBox[\"T1\",\nFontColor->RGBColor[0, 0, 1]]\) =  \
", 
             Round[$CellContext`T1, 0.01], "Nm"}, {
            "\!\(\*\nStyleBox[\"T\",\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*\n\
StyleBox[\"2\",\nFontColor->RGBColor[1, 0, 0]]\) = ", 
             Round[$CellContext`T2, 0.01], "Nm"}}, Alignment -> 
           Left]; $CellContext`dwf1$ = {
           Opacity[0.8], 
           Dashing[{}], 
           Thickness[0.002], 
           Arrowheads[0.02], 
           Arrow[{{0, 0, 0}, {0.075 $CellContext`L, 0, 0}}], 
           Arrow[{{0, 0, 0}, {0, 2. $CellContext`R0$, 0}}], 
           Arrow[{{0, 0, 0}, {0, 0, 2. $CellContext`R0$}}], FontSize -> 20, 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {
            0.09 $CellContext`L, 0, 0}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {
            0, 2.35 $CellContext`R0$, 0}], 
           Text[
           "\!\(\*\nStyleBox[\"z\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {
            0, 0, 2.35 $CellContext`R0$}]}; $CellContext`dwf2$ = {
           Opacity[0.8], Gray, 
           
           Cuboid[{(-0.1) $CellContext`R0$, (-1.25) $CellContext`R0$, (-1.25) \
$CellContext`R0$}, {
            0, 1.25 $CellContext`R0$, 
             1.25 $CellContext`R0$}]}; $CellContext`dwf3$ = {
           Opacity[0.4], Blue, 
           
           Cylinder[{{0, 0, 
             0}, {$CellContext`Pos$$, 0, 
              0}}, $CellContext`R1$$]}; $CellContext`dwf4$ = {
           Opacity[0.6], LightRed, 
           
           Cylinder[{{$CellContext`Pos$$, 0, 0}, {$CellContext`L, 0, 
              0}}, $CellContext`R2$$]}; $CellContext`dwf5$ = {
           Opacity[0.8], Gray, 
           
           Cuboid[{$CellContext`L, (-1.25) $CellContext`R0$, (-1.25) \
$CellContext`R0$}, {$CellContext`L + 0.1 $CellContext`R0$, 
             1.25 $CellContext`R0$, 
             1.25 $CellContext`R0$}]}; $CellContext`dwf6$ = {
           Opacity[1.2], 
           FaceForm[Black], 
           Polygon[
            
            Table[{$CellContext`Pos$$, 0.17 Cos[(2 Pi) ($CellContext`k/100)], 
              0.17 Sin[(2 Pi) ($CellContext`k/100)]}, {$CellContext`k, 0, 
              99}]]}; $CellContext`dwf7$ = {
           Opacity[0.8], Gray, 
           Rectangle[{-0.01, -0.125}, {0, 0.125}], 
           Rectangle[{$CellContext`L, -0.125}, {$CellContext`L + 0.01, 
             0.125}]}; $CellContext`dwf8$ = {
           Opacity[0.4], Blue, 
           
           Rectangle[{
            0, -$CellContext`R1$$}, {$CellContext`Pos$$, $CellContext`R1$$}], 
           Opacity[0.4], Red, 
           
           Rectangle[{$CellContext`Pos$$, -$CellContext`R2$$}, \
{$CellContext`L, $CellContext`R2$$}]}; $CellContext`dwf9$ = {
           Opacity[0.8], 
           Thickness[0.01], 
           
           Line[{{$CellContext`Pos$$, -0.3}, {$CellContext`Pos$$, 
              0.3}}]}; $CellContext`dwf10$ = {
           Opacity[0.8 $CellContext`opa$$], 
           Thickness[0.008], 
           Arrowheads[0.03], 
           
           Arrow[{{$CellContext`Pos$$ - $CellContext`F$$/500 + $CellContext`x,
               0}, {$CellContext`Pos$$, 0}}], FontSize -> 20, 
           Text[
           "\!\(\*\nStyleBox[\"F\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {$CellContext`Pos$$ - \
$CellContext`F$$/500 + 1.5 $CellContext`x, 0}]}; $CellContext`dwf11$ = {Black, 
           Thickness[0.002], 
           Line[{{$CellContext`L, 0}, {$CellContext`L, 2.15 $CellContext`R}}], 
           Line[{{0, 0}, {0, 2.15 $CellContext`R}}], Black, 
           Arrowheads[0.02], 
           
           Arrow[{{$CellContext`L, 2.15 $CellContext`R}, {
             0, 2.15 $CellContext`R}}], 
           
           Arrow[{{0, 2.15 $CellContext`R}, {$CellContext`L, 
              2.15 $CellContext`R}}], FontSize -> 14, 
           Text[
           "\!\(\*\nStyleBox[\"l\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., \
0.]]\)", {$CellContext`L/2, 2.35 $CellContext`R}], 
           Arrowheads[0.02], Blue, 
           
           Arrow[{{$CellContext`Pos$$, 1.5 $CellContext`R}, {
             0, 1.5 $CellContext`R}}], 
           
           Arrow[{{0, 1.5 $CellContext`R}, {$CellContext`Pos$$, 
              1.5 $CellContext`R}}], FontSize -> 14, 
           Text[
           "\!\(\*SubscriptBox[\n StyleBox[\"l\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0, 0, 1]], \n StyleBox[\"1\",\nFontColor->RGBColor[0, 0, \
1]]]\)", {$CellContext`Pos$$/2, 1.75 $CellContext`R}], 
           Arrowheads[0.02], Red, 
           
           Arrow[{{$CellContext`Pos$$, 1.5 $CellContext`R}, {$CellContext`L, 
              1.5 $CellContext`R}}], 
           
           Arrow[{{$CellContext`L, 1.5 $CellContext`R}, {$CellContext`Pos$$, 
              1.5 $CellContext`R}}], FontSize -> 14, 
           Text[
           "\!\(\*SubscriptBox[\n StyleBox[\"l\",\nFontFamily->\"Times New \
Roman\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[1, 0, 0]], \n StyleBox[\"2\",\nFontColor->RGBColor[1, 0, \
0]]]\)", {$CellContext`Pos$$ + ($CellContext`L - $CellContext`Pos$$)/2, 
             1.75 $CellContext`R}]}; $CellContext`dwf12$ = {
           Opacity[0.8 $CellContext`opa$$], Red, 
           Thickness[0.008], 
           Arrowheads[0.03], 
           
           Arrow[{{$CellContext`L, 
              0}, {$CellContext`L + $CellContext`F2/3000 + $CellContext`x, 
              0}}], FontSize -> 15, 
           Text[
           "F2", {$CellContext`L + 1.5 $CellContext`x + $CellContext`F2/3000, 
             0}], Blue, 
           Thickness[0.008], 
           Arrowheads[0.03], 
           Arrow[{{0, 0}, {(-$CellContext`F1)/3000 + $CellContext`x, 0}}], 
           FontSize -> 15, 
           Text[
           "F1", {(-$CellContext`F1)/3000 + 1.5 $CellContext`x, 
             0}]}; $CellContext`dwf13$ = {
           Opacity[((-0.8) ($CellContext`opa$$ - 1)) $CellContext`b], Red, 
           
           Cone[{{$CellContext`Pos$$, 0, 
              0.19}, {$CellContext`Pos$$, $CellContext`y 0.025, 0.19}}, 
            0.01 (1 - $CellContext`opa$$)], Black, FontSize -> 16, 
           Text[
           "\!\(\*\nStyleBox[\"T\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\",\nFontColor->RGBColor[0., 0., \
0.]]\)", {$CellContext`Pos$$, 0, 0.25}], Red, 
           Arrowheads[0.0001], 
           Thickness[$CellContext`T$$/200], 
           Arrow[
            
            Table[{$CellContext`Pos$$, 0.19 Cos[(2 Pi) ($CellContext`k/100)], 
              0.19 Sin[(2 Pi) ($CellContext`k/100)]}, {$CellContext`k, 0, 
              99}]]}; $CellContext`dwf14$ = {
           Opacity[$CellContext`opa$$ $CellContext`a], 
           Thickness[0.008], 
           Arrowheads[0.03], 
           
           Arrow[{{$CellContext`Pos$$ - $CellContext`F$$/750 + $CellContext`x,
               0, 0.17}, {$CellContext`Pos$$, 0, 0.17}}], FontSize -> 20, 
           Text[
           "\!\(\*\nStyleBox[\"F\",\nFontFamily->\"Times New Roman\",\n\
FontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)", {$CellContext`Pos$$ - \
$CellContext`F$$/750 + 1.5 $CellContext`x, 0, 0.17}], 
           
           Arrow[{{$CellContext`Pos$$ - $CellContext`F$$/750 + $CellContext`x,
               0, -0.17}, {$CellContext`Pos$$, 0, -0.17}}], 
           
           Arrow[{{$CellContext`Pos$$ - $CellContext`F$$/750 + $CellContext`x,
               0.17, 0}, {$CellContext`Pos$$, 0.17, 0}}], 
           
           Arrow[{{$CellContext`Pos$$ - $CellContext`F$$/
              750 + $CellContext`x, -0.17, 0}, {$CellContext`Pos$$, -0.17, 
              0}}], 
           
           Arrow[{{$CellContext`Pos$$ - $CellContext`F$$/750 + $CellContext`x,
               0.17/Sqrt[2], 0.17/Sqrt[2]}, {$CellContext`Pos$$, 0.17/Sqrt[2],
               0.17/Sqrt[2]}}], 
           
           Arrow[{{$CellContext`Pos$$ - $CellContext`F$$/
              750 + $CellContext`x, (-0.17)/Sqrt[2], (-0.17)/Sqrt[
              2]}, {$CellContext`Pos$$, (-0.17)/Sqrt[2], (-0.17)/Sqrt[2]}}], 
           
           Arrow[{{$CellContext`Pos$$ - $CellContext`F$$/750 + $CellContext`x,
               0.17/Sqrt[2], (-0.17)/Sqrt[2]}, {$CellContext`Pos$$, 0.17/Sqrt[
              2], (-0.17)/Sqrt[2]}}], 
           
           Arrow[{{$CellContext`Pos$$ - $CellContext`F$$/
              750 + $CellContext`x, (-0.17)/Sqrt[2], 0.17/Sqrt[
              2]}, {$CellContext`Pos$$, (-0.17)/Sqrt[2], 0.17/Sqrt[
              2]}}]}; $CellContext`dwf15$ = {}; $CellContext`dwf16$ = {
           Opacity[(-0.8) ($CellContext`opa$$ - 1)], Black, 
           Circle[{$CellContext`Pos$$, 0.375}, 0.025], 
           If[$CellContext`y == 1, 
            Text["X", {$CellContext`Pos$$, 0.375}], 
            Point[{$CellContext`Pos$$, 0.375}]], Black, 
           Circle[{0, 0.3}, 0.025], 
           If[$CellContext`y == -1, 
            Text["X", {0, 0.3}], 
            Point[{0, 0.3}]], Black, 
           Circle[{$CellContext`L, 0.3}, 0.025], 
           If[$CellContext`y == -1, 
            Text["X", {$CellContext`L, 0.3}], 
            Point[{$CellContext`L, 0.3}]], Black, FontSize -> 14, 
           
           Text[$CellContext`T$$ 
            "kN\[CenterDot]m", {$CellContext`Pos$$, 0.45}], 
           Text[
           "\!\(\*\nStyleBox[\"T1\",\nFontColor->RGBColor[0, 0, 1]]\)", {
            0, 0.35}], 
           Text[
           "\!\(\*\nStyleBox[\"T2\",\nFontColor->RGBColor[1, 0, 0]]\)", \
{$CellContext`L, 0.35}], 
           Text[
           "\!\(\*\nStyleBox[\"T\",\nFontWeight->\"Plain\"]\)\!\(\*\n\
StyleBox[\"=\",\nFontWeight->\"Plain\"]\)", {$CellContext`Pos$$, 
             0.5}]}; $CellContext`dw1$ = 
         Graphics3D[{$CellContext`dwf1$, $CellContext`dwf2$, \
$CellContext`dwf3$, $CellContext`dwf4$, $CellContext`dwf5$, \
$CellContext`dwf6$, $CellContext`dwf13$, $CellContext`dwf14$}, \
$CellContext`settings1$, 
           PreserveImageOptions -> $CellContext`reset1$]; $CellContext`dw2$ = 
         Graphics[{$CellContext`dwf7$, $CellContext`dwf8$, \
$CellContext`dwf9$, $CellContext`dwf10$, $CellContext`dwf11$, \
$CellContext`dwf12$, $CellContext`dwf15$, $CellContext`dwf16$}, \
$CellContext`settings2$]; Column[{
           Text[
            
            Grid[{{"Input Parameters and Calculated Values", SpanFromLeft}, {
              "Shaft", "L[m]", "R[m]", "E[GPa]", "G[MPa]"}, {
              "\!\(\*\nStyleBox[\"1\",\nFontColor->RGBColor[0, 0, 1]]\)", 
               
               Round[$CellContext`Pos$$, 
                0.01], $CellContext`R1$$, $CellContext`E1$$, \
$CellContext`G1$$}, {
              "\!\(\*\nStyleBox[\"2\",\nFontColor->RGBColor[1, 0, 0]]\)", 
               
               Round[$CellContext`L - $CellContext`Pos$$, 
                0.01], $CellContext`R2$$, $CellContext`E2$$, \
$CellContext`G2$$}}, ItemSize -> 5, Frame -> All, Background -> {None, {
                Lighter[Gray, 0.95]}}]], 
           Show[$CellContext`dw1$], 
           Show[$CellContext`dw2$]}, Alignment -> Center]], 
      "Specifications" :> {{{$CellContext`pv$$, 0, 
          Row[{"Point of View", 
            Spacer[10]}]}, {0 -> "3D", 1 -> "Y-Z Plane", 2 -> "X-Y Plane"}, 
         ControlType -> RadioButton, ControlPlacement -> 
         1}, {{$CellContext`Pos$$, 0.5, 
          Row[{"Position of Loading Force or Torque", 
            Spacer[10]}]}, 0.01, 0.99, 0.01, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 2}, {{$CellContext`R1$$, 0.1, 
          Row[{"Radius of Shaft 1 [m]", 
            Spacer[85]}]}, 0.025, 0.1, 0.01, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 3}, {{$CellContext`R2$$, 0.05, 
          Row[{"Radius of Shaft 2 [m]", 
            Spacer[85]}]}, 0.025, 0.1, 0.01, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 4}, {{$CellContext`opa$$, 1, 
          
          Row[{"\!\(\*\nStyleBox[\"Switch\",\nFontWeight->\"Bold\"]\)\!\(\*\n\
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*\nStyleBox[\"Mode\",\n\
FontWeight->\"Bold\"]\)", 
            Spacer[22]}]}, {1 -> "Force", 0 -> "Torque"}, ControlType -> 
         PopupMenu, ImageSize -> Large, ControlPlacement -> 
         5}, {{$CellContext`F$$, 10, 
          Row[{"Force Applied on the Disk [N]", 
            Spacer[45]}]}, -100, 100, 0.1, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 6}, {{$CellContext`E1$$, 200, 
          Row[{"Young's Modulus of Shaft 1 [GPa]", 
            Spacer[22]}]}, 0, 200, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 7}, {{$CellContext`E2$$, 200, 
          Row[{"Young's Modulus of Shaft 2 [GPa]", 
            Spacer[22]}]}, 0, 200, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 8}, {{$CellContext`opa1$$, 0, 
          Row[{"Show Result", 
            Spacer[10]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> SetterBar, 
         ControlPlacement -> 9}, {{$CellContext`T$$, 0.5, 
          Row[{"Torque Applied on the Disk [kN\[CenterDot]m]", 
            Spacer[38]}]}, -1, 1, 0.01, ImageSize -> Small, Appearance -> 
         "Labeled", ControlPlacement -> 10}, {{$CellContext`G1$$, 4, 
          Row[{"Shear Modulus of Shaft 1 [MPa]", 
            Spacer[50]}]}, 4, 10, ImageSize -> Small, Appearance -> "Labeled",
          ControlPlacement -> 11}, {{$CellContext`G2$$, 4, 
          Row[{"Shear Modulus of Shaft 2 [MPa]", 
            Spacer[50]}]}, 4, 10, ImageSize -> Small, Appearance -> "Labeled",
          ControlPlacement -> 12}, {{$CellContext`opa2$$, 0, 
          Row[{"Show Result", 
            Spacer[10]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> SetterBar, 
         ControlPlacement -> 13}, 
        Grid[{{
           Manipulate`Place[1]}, {
           Button[
           "Reset view", $CellContext`reset$$ = True, 
            ImageSize -> {90, 30}]}, {
           Manipulate`Place[2]}, {
           Manipulate`Place[3]}, {
           Manipulate`Place[4]}, {
           Row[{"--------------------------------------------------"}]}, {
           Manipulate`Place[5]}, {
           PaneSelector[{1 -> Column[{
                
                Row[{"\!\(\*\nStyleBox[\"Type\",\n\
FontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\"]\)\!\(\
\*\nStyleBox[\"I\",\nFontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\":\",\n\
FontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\"]\)\!\(\
\*\nStyleBox[\"Force\",\nFontWeight->\"Plain\"]\)"}], 
                Manipulate`Place[6], 
                Manipulate`Place[7], 
                Manipulate`Place[8], 
                Manipulate`Place[9], 
                Row[{
                  Dynamic[
                   If[$CellContext`opa1$$ == 1, $CellContext`label1, 
                    Invisible[$CellContext`temp]]]}]}, Spacings -> 1.75], 0 -> 
             Column[{
                
                Row[{"\!\(\*\nStyleBox[\"Type\",\n\
FontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\"]\)\!\(\
\*\nStyleBox[\"II\",\nFontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\":\",\n\
FontWeight->\"Plain\"]\)\!\(\*\nStyleBox[\" \",\nFontWeight->\"Plain\"]\)\!\(\
\*\nStyleBox[\"Torque\",\nFontWeight->\"Plain\"]\)"}], 
                Manipulate`Place[10], 
                Manipulate`Place[11], 
                Manipulate`Place[12], 
                Manipulate`Place[13], 
                Row[{
                  Dynamic[
                   If[$CellContext`opa2$$ == 1, $CellContext`label2, 
                    Invisible[$CellContext`temp]]]}]}, Spacings -> 1.75]}, 
            Dynamic[$CellContext`opa$$]]}}, Alignment -> Left, 
         Spacings -> {Automatic, 1.5}], {{$CellContext`reset$$, False}, 0, 
         ControlType -> None}}, "Options" :> {ControlPlacement -> Left}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{1162., {520., 527.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 ExpressionUUID -> "f636c325-dc0a-4a38-a7d6-7458f3506840"]
},
WindowSize->{1366, 685},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.25 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[1464, 33, 315, 8, 148, "Text"],
Cell[1782, 43, 2373, 56, 236, "Text"],
Cell[4158, 101, 26333, 526, 1067, "Output"]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature Uw0X6HqJZnkLCBgnu7Z6j#pM *)
